import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class QuestionableContent(BasicComicModule):
    latestUrl = 'http://www.questionablecontent.net/'
    imageUrl = 'http://www.questionablecontent.net/view.php?comic=%s'
    imageSearch = re.compile(r'<img src="(\.{1,2}/comics/\d+\.png)"')
    prevSearch = re.compile(r'<a href="(view.php\?comic=\d+)">Previous')
    help = 'Index format: n (unpadded)'
